@@ -1,7 +1,7 @@
 var servicecom_1_1sun_1_1star_1_1table_1_1TableRow =
 [
-    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
-    [ "XCellRange", "servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html#a695b26055647481e5442ec825165158b", null ],
+    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::table::XCellRange", "servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html#a695b26055647481e5442ec825165158b", null ],
     [ "Height", "servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html#ae419f6e85ca63aca1b00db3e46953e83", null ],
     [ "IsStartOfNewPage", "servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html#a05723b3f409c70881a51a152a581e8ab", null ],
     [ "IsVisible", "servicecom_1_1sun_1_1star_1_1table_1_1TableRow.html#a9a886e02e55d4f1dbabbb84da0ae7e7f", null ],
